@@ -1,3 +1,4 @@
+from .const import DATA
 from .requests import (
     connect_to_gateway,
     request_gateway_version,
@@ -9,6 +10,7 @@ from .requests import (
     request_set_heat_mode,
     request_set_heat_setpoint,
     request_chemistry,
+    request_scg_config,
 )
 
 
@@ -22,6 +24,7 @@ class ScreenLogicGateway:
         self.__subtype = gsubtype
         self.__name = name
         self.__mac = ""
+        self.__version = ""
         self.__connected = False
         self.__data = {}
 
@@ -31,6 +34,7 @@ class ScreenLogicGateway:
                 self._get_status()
                 self._get_pumps()
                 self._get_chemistry()
+                self._get_scg()
                 self._disconnect()
         else:
             raise ValueError("Invalid ip or port")
@@ -51,11 +55,16 @@ class ScreenLogicGateway:
     def mac(self):
         return self.__mac
 
+    @property
+    def version(self):
+        return self.__version
+
     def update(self):
         if (self.is_connected or self._connect()) and self.__data:
             self._get_status()
             self._get_pumps()
             self._get_chemistry()
+            self._get_scg()
             self._disconnect()
 
     def get_data(self):
@@ -101,7 +110,6 @@ class ScreenLogicGateway:
         soc_mac = connect_to_gateway(self.__ip, self.__port)
         if soc_mac:
             self.__socket, self.__mac = soc_mac
-            self.__version = ""
             self.__version = request_gateway_version(self.__socket)
             if self.__version:
                 self.__connected = True
@@ -123,27 +131,31 @@ class ScreenLogicGateway:
 
     def _get_pumps(self):
         if self.__connected or self._connect():
-            for pID in self.__data["pumps"]:
-                if self.__data["pumps"][pID]["data"] != 0:
+            for pID in self.__data[DATA.KEY_PUMPS]:
+                if self.__data[DATA.KEY_PUMPS][pID]["data"] != 0:
                     request_pump_status(self.__socket, self.__data, pID)
 
     def _get_chemistry(self):
         if self.__connected or self._connect():
             request_chemistry(self.__socket, self.__data)
 
+    def _get_scg(self):
+        if self.__connected or self._connect():
+            request_scg_config(self.__socket, self.__data)
+
     def _is_valid_circuit(self, circuit):
-        return circuit in self.__data["circuits"]
+        return circuit in self.__data[DATA.KEY_CIRCUITS]
 
     def _is_valid_circuit_state(self, state):
         return state == 0 or state == 1
 
     def _is_valid_body(self, body):
-        return body in self.__data["bodies"]
+        return body in self.__data[DATA.KEY_BODIES]
 
     def _is_valid_heatmode(self, heatmode):
         return 0 <= heatmode < 5
 
     def _is_valid_heattemp(self, body, temp):
-        min_temp = self.__data["bodies"][int(body)]["min_set_point"]["value"]
-        max_temp = self.__data["bodies"][int(body)]["max_set_point"]["value"]
+        min_temp = self.__data[DATA.KEY_BODIES][int(body)]["min_set_point"]["value"]
+        max_temp = self.__data[DATA.KEY_BODIES][int(body)]["max_set_point"]["value"]
         return min_temp <= temp <= max_temp
