@@ -1,10 +1,8 @@
 # import json
 import struct
-from ..const import CHEMISTRY, code, DATA, DEVICE_TYPE, ON_OFF, UNIT
+from ..const import ADD_UNKNOWN_VALUES, CHEMISTRY, code, DATA, DEVICE_TYPE, ON_OFF, UNIT
 from .utility import sendReceiveMessage, getSome
 
-ADD_UNKNOWNS = False
-
 
 def request_chemistry(gateway_socket, data):
     response = sendReceiveMessage(
@@ -67,28 +65,28 @@ def decode_chemistry(buff, data):
     chemistry["ph_last_dose_time"] = {
         "name": "Last pH Dose Time",
         "value": pHDoseTime,
-        "unit": "Sec" 
+        "unit": "Sec",
     }
-    
+
     orpDoseTime, offset = getSome(">I", buff, offset)  # 13
     chemistry["orp_last_dose_time"] = {
         "name": "Last ORP Dose Time",
         "value": orpDoseTime,
-        "unit": "Sec" 
+        "unit": "Sec",
     }
 
     pHDoseVolume, offset = getSome(">H", buff, offset)  # 17
     chemistry["ph_last_dose_volume"] = {
         "name": "Last pH Dose Volume",
         "value": pHDoseVolume,
-        "unit": "mL" 
+        "unit": "mL",
     }
-    
+
     orpDoseVolume, offset = getSome(">H", buff, offset)  # 19
     chemistry["orp_last_dose_volume"] = {
         "name": "Last ORP Dose Volume",
         "value": orpDoseVolume,
-        "unit": "mL" 
+        "unit": "mL",
     }
 
     pHSupplyLevel, offset = getSome("B", buff, offset)  # 21 (20)
@@ -127,7 +125,11 @@ def decode_chemistry(buff, data):
     }
 
     saltPPM, offset = getSome("B", buff, offset)  # 30
-    chemistry["salt_ppm"] = {"name": "Salt", "value": (saltPPM * 50), "unit": "ppm"}
+    chemistry["salt_tds_ppm"] = {
+        "name": "Salt/TDS",
+        "value": (saltPPM * 50),
+        "unit": "ppm",
+    }
 
     # Probe temp unit is Celsius?
     probIsC, offset = getSome("B", buff, offset)
@@ -150,26 +152,32 @@ def decode_chemistry(buff, data):
     alerts["flow_alarm"] = {
         "name": "Flow Alarm",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_FLOW)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
     alerts["ph_alarm"] = {
         "name": "pH Alarm",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_PH)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
     alerts["orp_alarm"] = {
         "name": "ORP Alarm",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_ORP)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
     alerts["ph_supply_alarm"] = {
         "name": "pH Supply Alarm",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_PH_SUPPLY)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
     alerts["orp_supply_alarm"] = {
         "name": "ORP Supply Alarm",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_ORP_SUPPLY)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
     alerts["probe_fault_alarm"] = {
         "name": "Probe Fault",
         "value": ON_OFF.from_bool(is_set(alarms, CHEMISTRY.FLAG_ALARM_PROBE_FAULT)),
+        "device_type": DEVICE_TYPE.ALARM,
     }
 
     if DATA.KEY_NOTIFICATIONS not in chemistry:
@@ -232,7 +240,7 @@ def decode_chemistry(buff, data):
     last4, offset = getSome("B", buff, offset)  # 42
     unknown["last4"] = last4
 
-    if ADD_UNKNOWNS:
+    if ADD_UNKNOWN_VALUES:
         chemistry["unknown"] = unknown
 
     # print(json.dumps(data, indent=4))
