@@ -1,10 +1,10 @@
 import struct
-from .utility import sendRecieveMessage
+from .utility import sendReceiveMessage
 from ..const import code
 
 
 def request_set_heat_setpoint(gateway_socket, body, setpoint):
-    response = sendRecieveMessage(
+    response = sendReceiveMessage(
         gateway_socket, code.SETHEATTEMP_QUERY, struct.pack("<III", 0, body, setpoint)
     )
     if response == b"":
@@ -14,7 +14,7 @@ def request_set_heat_setpoint(gateway_socket, body, setpoint):
 
 
 def request_set_heat_mode(gateway_socket, body, heat_mode):
-    response = sendRecieveMessage(
+    response = sendReceiveMessage(
         gateway_socket, code.SETHEATMODE_QUERY, struct.pack("<III", 0, body, heat_mode)
     )
     if response == b"":
